@@ -2,39 +2,10 @@
  * Symbols used everywhere.
  * Eventually, we should collect all the global symbols and
  * put them here.
- *
- * ----------------------------------------------------------------
- *
- * @begin[license]
- * Copyright (C) 2004-2007 Mojave Group, California Institute of Technology, and
- * HRL Laboratories, LLC
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; version 2
- * of the License.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
- * Additional permission is given to link this library with the
- * with the Objective Caml runtime, and to redistribute the
- * linked executables.  See the file LICENSE.OMake for more details.
- *
- * Author: Jason Hickey @email{jyh@cs.caltech.edu}
- * Modified By: Aleksey Nogin @email{anogin@hrl.com}
- * @end[license]
  *)
-open Lm_symbol
+
 
 let braces_sym                 = Lm_symbol.add "{}"
-
 let builtin_sym                = Lm_symbol.add "$builtin"
 let map_sym                    = Lm_symbol.add "$map"
 let pervasives_sym             = Lm_symbol.add "Pervasives"
@@ -65,6 +36,7 @@ let location_object_sym        = Lm_symbol.add "Location"
 let target_object_sym          = Lm_symbol.add "Target"
 let options_object_sym         = Lm_symbol.add "Options"
 let var_object_sym             = Lm_symbol.add "Var"
+let tm_object_sym              = Lm_symbol.add "Tm"
 
 let wild_sym                   = Lm_symbol.add "%"
 let explicit_target_sym        = Lm_symbol.add "$EXPLICIT-TARGET"
@@ -73,7 +45,7 @@ let current_prec_sym           = Lm_symbol.add "current-prec"
 
 let lex_sym                    = Lm_symbol.add "lex"
 let name_sym                   = Lm_symbol.add "name"
-let value_sym                  = Lm_symbol.add "value"
+(* let value_sym                  = Lm_symbol.add "value" *)
 let lexer_sym                  = Lm_symbol.add "lexer"
 let val_sym                    = Lm_symbol.add "val"
 
@@ -81,18 +53,18 @@ let read_sym                   = Lm_symbol.add "read"
 let write_sym                  = Lm_symbol.add "write"
 let error_sym                  = Lm_symbol.add "error"
 
-let st_dev_sym                 = Lm_symbol.add "dev"
-let st_ino_sym                 = Lm_symbol.add "ino"
-let st_kind_sym                = Lm_symbol.add "kind"
-let st_perm_sym                = Lm_symbol.add "perm"
-let st_nlink_sym               = Lm_symbol.add "nlink"
-let st_uid_sym                 = Lm_symbol.add "uid"
-let st_gid_sym                 = Lm_symbol.add "gid"
-let st_rdev_sym                = Lm_symbol.add "rdev"
-let st_size_sym                = Lm_symbol.add "size"
-let st_atime_sym               = Lm_symbol.add "atime"
-let st_mtime_sym               = Lm_symbol.add "mtime"
-let st_ctime_sym               = Lm_symbol.add "ctime"
+let st_dev_sym                 = Lm_symbol.add "st_dev"
+let st_ino_sym                 = Lm_symbol.add "st_ino"
+let st_kind_sym                = Lm_symbol.add "st_kind"
+let st_perm_sym                = Lm_symbol.add "st_perm"
+let st_nlink_sym               = Lm_symbol.add "st_nlink"
+let st_uid_sym                 = Lm_symbol.add "st_uid"
+let st_gid_sym                 = Lm_symbol.add "st_gid"
+let st_rdev_sym                = Lm_symbol.add "st_rdev"
+let st_size_sym                = Lm_symbol.add "st_size"
+let st_atime_sym               = Lm_symbol.add "st_atime"
+let st_mtime_sym               = Lm_symbol.add "st_mtime"
+let st_ctime_sym               = Lm_symbol.add "st_ctime"
 
 let pw_name_sym                = Lm_symbol.add "pw_name"
 let pw_passwd_sym              = Lm_symbol.add "pw_passwd"
@@ -107,6 +79,17 @@ let gr_passwd_sym              = Lm_symbol.add "gr_passwd"
 let gr_gid_sym                 = Lm_symbol.add "gr_gid"
 let gr_mem_sym                 = Lm_symbol.add "gr_mem"
 
+let tm_sec_sym                 = Lm_symbol.add "tm_sec"
+let tm_min_sym                 = Lm_symbol.add "tm_min"
+let tm_hour_sym                = Lm_symbol.add "tm_hour"
+let tm_mday_sym                = Lm_symbol.add "tm_mday"
+let tm_mon_sym                 = Lm_symbol.add "tm_mon"
+let tm_year_sym                = Lm_symbol.add "tm_year"
+let tm_wday_sym                = Lm_symbol.add "tm_wday"
+let tm_yday_sym                = Lm_symbol.add "tm_yday"
+let tm_isdst_sym               = Lm_symbol.add "tm_isdst"
+let tm_time_sym                = Lm_symbol.add "tm_time"
+
 let target_sym                 = Lm_symbol.add "target"
 let target_effects_sym         = Lm_symbol.add "effects"
 let scanner_deps_sym           = Lm_symbol.add "scanner-deps"
@@ -181,6 +164,7 @@ let try_sym       = Lm_symbol.add "try"
 let catch_sym     = Lm_symbol.add "catch"
 let when_sym      = Lm_symbol.add "when"
 let finally_sym   = Lm_symbol.add "finally"
+let curry_sym     = Lm_symbol.add "curry"
 let private_sym   = Lm_symbol.add "private"
 let protected_sym = Lm_symbol.add "protected"
 let public_sym    = Lm_symbol.add "public"
@@ -196,9 +180,34 @@ let export_sym    = Lm_symbol.add "export"
 let value_sym     = Lm_symbol.add "value"
 let file_sym      = Lm_symbol.add "__FILE__"
 let file_id_sym   = Lm_symbol.add "__ID__"
+let foreach_sym   = Lm_symbol.add "foreach"
+let fun_sym       = Lm_symbol.add "fun"
 let set_sym       = Lm_symbol.add "set"
 
+let neg_fun_sym       = Lm_symbol.add "neg"
+let add_fun_sym       = Lm_symbol.add "add"
+let sub_fun_sym       = Lm_symbol.add "sub"
+let mul_fun_sym       = Lm_symbol.add "mul"
+let div_fun_sym       = Lm_symbol.add "div"
+let mod_fun_sym       = Lm_symbol.add "mod"
+let lsl_fun_sym       = Lm_symbol.add "lsl"
+let lsr_fun_sym       = Lm_symbol.add "lsr"
+let asr_fun_sym       = Lm_symbol.add "asr"
+let lxor_fun_sym      = Lm_symbol.add "lxor"
+let lor_fun_sym       = Lm_symbol.add "lor"
+let land_fun_sym      = Lm_symbol.add "land"
+let and_fun_sym       = Lm_symbol.add "and"
+let or_fun_sym        = Lm_symbol.add "or"
+let le_fun_sym        = Lm_symbol.add "le"
+let lt_fun_sym        = Lm_symbol.add "lt"
+let equal_fun_sym     = Lm_symbol.add "equal"
+let nequal_fun_sym    = Lm_symbol.add "nequal"
+let ge_fun_sym        = Lm_symbol.add "ge"
+let gt_fun_sym        = Lm_symbol.add "gt"
+let nth_fun_sym       = Lm_symbol.add "nth"
+
 let memo_rule_sym       = Lm_symbol.add "memo-rule"
+
 let empty_map_sym       = Lm_symbol.add "empty-map"
 let create_map_sym      = Lm_symbol.add "create-map"
 let create_lazy_map_sym = Lm_symbol.add "create-lazy-map"
@@ -220,10 +229,10 @@ let fsubst_sym    = Lm_symbol.add "fsubst"
  * The applications that can have cases.
  *)
 let cases_syms    = [awk_sym; fsubst_sym]
-let cases_set     = List.fold_left SymbolSet.add SymbolSet.empty cases_syms
+let cases_set     = List.fold_left Lm_symbol.SymbolSet.add Lm_symbol.SymbolSet.empty cases_syms
 
 let clauses_syms  = [case_sym; default_sym; when_sym; catch_sym; finally_sym; do_sym]
-let clauses_set   = List.fold_left SymbolSet.add SymbolSet.empty clauses_syms
+let clauses_set   = List.fold_left Lm_symbol.SymbolSet.add Lm_symbol.SymbolSet.empty clauses_syms
 
 (*
  * Colon symbols.
@@ -262,10 +271,3 @@ let omakepath_sym = Lm_symbol.add "OMAKEPATH"
 let oshell_sym    = Lm_symbol.add "OSHELL"
 
 let cdpath_sym    = Lm_symbol.add "cdpath"
-
-(*
- * -*-
- * Local Variables:
- * End:
- * -*-
- *)
